@@ -8,7 +8,7 @@ use Import::Export;
 
 use base qw/Import::Export/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our %EX = (
 	entropy => [qw/all/]
@@ -16,10 +16,7 @@ our %EX = (
 
 sub entropy {
 	my ($entropy, $p, %t) = 0;
-	return (do {
-		map { $p = $_/length($_[0]); $entropy -= $p * log $p } (map { $t{$_}++ } split '', $_[0]) && values %t;
-		$entropy;
-	} / log 2);
+	return ((map { $p = $_/length($_[0]); $entropy -= $p * log $p } (map { $t{$_}++ } split '', $_[0]) && values %t) and $entropy / log 2);
 }
 
 =head1 NAME
@@ -28,7 +25,7 @@ Shannon::Entropy - Calculate the Shannon entropy H of a given input string.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
